==> haskell-socks-0.5.6-55-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-socks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: socks
version: 0.5.6
id: socks-0.5.6-KJco1fv2owwLGI43w4S61C
key: socks-0.5.6-KJco1fv2owwLGI43w4S61C
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-socks
synopsis: Socks proxy (ver 5)
description:
    Socks proxy (version 5) implementation.
category: Network
abi: ca55e8848a4fe370cade181c512dcfa2
exposed: True
exposed-modules:
    Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types
hidden-modules: Network.Socks5.Wire Network.Socks5.Conf
                Network.Socks5.Command Network.Socks5.Parse
import-dirs: /usr/lib/ghc-8.6.5/site-local/socks-0.5.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/socks-0.5.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/socks-0.5.6
hs-libraries: HSsocks-0.5.6-KJco1fv2owwLGI43w4S61C
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.8.0-DifhRWa8By0JYDe2id7eOT
    network-2.8.0.0-A0G1UJzDIGiEvzFah0DnI2
haddock-interfaces: /usr/share/doc/haskell-socks/html/socks.haddock
haddock-html: /usr/share/doc/haskell-socks/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-socks-0.6.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-socks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: socks
version: 0.6.0
id: socks-0.6.0-HoPdQ7SxVbbKNOns6PS6vk
key: socks-0.6.0-HoPdQ7SxVbbKNOns6PS6vk
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-socks
synopsis: Socks proxy (ver 5)
description:
    Socks proxy (version 5) implementation.
category: Network
abi: 021ad3f7064fadb6936854ac1d2ba2c6
exposed: True
exposed-modules:
    Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types
hidden-modules: Network.Socks5.Wire Network.Socks5.Conf
                Network.Socks5.Command Network.Socks5.Parse
import-dirs: /usr/lib/ghc-8.6.5/site-local/socks-0.6.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/socks-0.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/socks-0.6.0
hs-libraries: HSsocks-0.6.0-HoPdQ7SxVbbKNOns6PS6vk
depends:
    base-4.12.0.0 basement-0.0.10-2z2JaOuy7fVLQL3Bi1dEbr
    bytestring-0.10.8.2 cereal-0.5.8.0-DifhRWa8By0JYDe2id7eOT
    network-2.8.0.0-A0G1UJzDIGiEvzFah0DnI2
haddock-interfaces: /usr/share/doc/haskell-socks/html/socks.haddock
haddock-html: /usr/share/doc/haskell-socks/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
